summaryrefslogtreecommitdiff
path: root/src/include/taler_merchant_service.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/taler_merchant_service.h')
-rw-r--r--src/include/taler_merchant_service.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/include/taler_merchant_service.h b/src/include/taler_merchant_service.h
index 30059639..46e6ec9f 100644
--- a/src/include/taler_merchant_service.h
+++ b/src/include/taler_merchant_service.h
@@ -963,7 +963,7 @@ struct TALER_MERCHANT_CheckPaymentOperation;
* #GNUNET_NO if refunded, #GNUNET_SYSERR or error
* @param refunded_amount amount that was refunded, NULL if there
* was no refund
* @param payment_redirect_url URL to redirect the browser to in order to
* execute or re-play the payment (NULL if not applicable)
*/
typedef void
@@ -973,7 +973,7 @@ typedef void
int paid,
int refunded,
struct TALER_Amount *refund_amount,
- const char *payment_redirect_url);
+ const char *fallback_request_payment_url);
/**
@@ -963,7 +963,7 @@ struct TALER_MERCHANT_CheckPaymentOperation;
* @param refunded_amount amount that was refunded, NULL if there
* was no refund
- * @param payment_redirect_url URL to redirect the browser to in order to
+ * @param fallback_request_payment_url URL to redirect the browser to in order to
* execute or re-play the payment (NULL if not applicable)
*/